@@ -1,3 +1,4 @@
+from email.policy import default
 from typing import Optional
 
 from fastapi_camelcase import CamelModel
@@ -7,6 +8,6 @@ from telus_bulk.models.ams.zone_attribute import ZoneAttributes
 
 
 class ZoneInfoItem(CamelModel):
-    zone_type: str = Field(..., alias="zoneType")
-    zone_name: str = Field(..., alias="zoneName")
+    zone_type: Optional[str] = Field(default=None, alias="zoneType")
+    zone_name: Optional[str] = Field(default=None, alias="zoneName")
     zone_attributes: Optional[ZoneAttributes] = Field(None, alias="zoneAttributes")
